==> chaosmesh-model-6.6.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/PhysicalMachineChaosFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PhysicalMachineChaosFluentImpl<A extends PhysicalMachineChaosFluent<A>> extends BaseFluent<A> implements PhysicalMachineChaosFluent<A>{
  public PhysicalMachineChaosFluentImpl() {
  }
  public PhysicalMachineChaosFluentImpl(PhysicalMachineChaos instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private PhysicalMachineChaosSpecBuilder spec;
  private PhysicalMachineChaosStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public PhysicalMachineChaosFluent.MetadataNested<A> withNewMetadata() {
    return new PhysicalMachineChaosFluentImpl.MetadataNestedImpl();
  }
  public PhysicalMachineChaosFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new PhysicalMachineChaosFluentImpl.MetadataNestedImpl(item);
  }
  public PhysicalMachineChaosFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public PhysicalMachineChaosFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public PhysicalMachineChaosFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public PhysicalMachineChaosSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public PhysicalMachineChaosSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(PhysicalMachineChaosSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new PhysicalMachineChaosSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public PhysicalMachineChaosFluent.SpecNested<A> withNewSpec() {
    return new PhysicalMachineChaosFluentImpl.SpecNestedImpl();
  }
  public PhysicalMachineChaosFluent.SpecNested<A> withNewSpecLike(PhysicalMachineChaosSpec item) {
    return new PhysicalMachineChaosFluentImpl.SpecNestedImpl(item);
  }
  public PhysicalMachineChaosFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public PhysicalMachineChaosFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new PhysicalMachineChaosSpecBuilder().build());
  }
  public PhysicalMachineChaosFluent.SpecNested<A> editOrNewSpecLike(PhysicalMachineChaosSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public PhysicalMachineChaosStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public PhysicalMachineChaosStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(PhysicalMachineChaosStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new PhysicalMachineChaosStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public PhysicalMachineChaosFluent.StatusNested<A> withNewStatus() {
    return new PhysicalMachineChaosFluentImpl.StatusNestedImpl();
  }
  public PhysicalMachineChaosFluent.StatusNested<A> withNewStatusLike(PhysicalMachineChaosStatus item) {
    return new PhysicalMachineChaosFluentImpl.StatusNestedImpl(item);
  }
  public PhysicalMachineChaosFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public PhysicalMachineChaosFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new PhysicalMachineChaosStatusBuilder().build());
  }
  public PhysicalMachineChaosFluent.StatusNested<A> editOrNewStatusLike(PhysicalMachineChaosStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PhysicalMachineChaosFluentImpl that = (PhysicalMachineChaosFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<PhysicalMachineChaosFluent.MetadataNested<N>> implements PhysicalMachineChaosFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) PhysicalMachineChaosFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends PhysicalMachineChaosSpecFluentImpl<PhysicalMachineChaosFluent.SpecNested<N>> implements PhysicalMachineChaosFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(PhysicalMachineChaosSpec item) {
      this.builder = new PhysicalMachineChaosSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new PhysicalMachineChaosSpecBuilder(this);
    }
    PhysicalMachineChaosSpecBuilder builder;
    public N and() {
      return (N) PhysicalMachineChaosFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends PhysicalMachineChaosStatusFluentImpl<PhysicalMachineChaosFluent.StatusNested<N>> implements PhysicalMachineChaosFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(PhysicalMachineChaosStatus item) {
      this.builder = new PhysicalMachineChaosStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new PhysicalMachineChaosStatusBuilder(this);
    }
    PhysicalMachineChaosStatusBuilder builder;
    public N and() {
      return (N) PhysicalMachineChaosFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> chaosmesh-model-6.7.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/PhysicalMachineChaosFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PhysicalMachineChaosFluentImpl<A extends PhysicalMachineChaosFluent<A>> extends BaseFluent<A> implements PhysicalMachineChaosFluent<A>{
  public PhysicalMachineChaosFluentImpl() {
  }
  public PhysicalMachineChaosFluentImpl(PhysicalMachineChaos instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private PhysicalMachineChaosSpecBuilder spec;
  private PhysicalMachineChaosStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public PhysicalMachineChaosFluentImpl.MetadataNested<A> withNewMetadata() {
    return new PhysicalMachineChaosFluentImpl.MetadataNestedImpl();
  }
  public PhysicalMachineChaosFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new PhysicalMachineChaosFluentImpl.MetadataNestedImpl(item);
  }
  public PhysicalMachineChaosFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public PhysicalMachineChaosFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public PhysicalMachineChaosFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public PhysicalMachineChaosSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public PhysicalMachineChaosSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(PhysicalMachineChaosSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new PhysicalMachineChaosSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public PhysicalMachineChaosFluentImpl.SpecNested<A> withNewSpec() {
    return new PhysicalMachineChaosFluentImpl.SpecNestedImpl();
  }
  public PhysicalMachineChaosFluentImpl.SpecNested<A> withNewSpecLike(PhysicalMachineChaosSpec item) {
    return new PhysicalMachineChaosFluentImpl.SpecNestedImpl(item);
  }
  public PhysicalMachineChaosFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public PhysicalMachineChaosFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new PhysicalMachineChaosSpecBuilder().build());
  }
  public PhysicalMachineChaosFluentImpl.SpecNested<A> editOrNewSpecLike(PhysicalMachineChaosSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public PhysicalMachineChaosStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public PhysicalMachineChaosStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(PhysicalMachineChaosStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new PhysicalMachineChaosStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public PhysicalMachineChaosFluentImpl.StatusNested<A> withNewStatus() {
    return new PhysicalMachineChaosFluentImpl.StatusNestedImpl();
  }
  public PhysicalMachineChaosFluentImpl.StatusNested<A> withNewStatusLike(PhysicalMachineChaosStatus item) {
    return new PhysicalMachineChaosFluentImpl.StatusNestedImpl(item);
  }
  public PhysicalMachineChaosFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public PhysicalMachineChaosFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new PhysicalMachineChaosStatusBuilder().build());
  }
  public PhysicalMachineChaosFluentImpl.StatusNested<A> editOrNewStatusLike(PhysicalMachineChaosStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PhysicalMachineChaosFluentImpl that = (PhysicalMachineChaosFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<PhysicalMachineChaosFluentImpl.MetadataNested<N>> implements PhysicalMachineChaosFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) PhysicalMachineChaosFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends PhysicalMachineChaosSpecFluentImpl<PhysicalMachineChaosFluentImpl.SpecNested<N>> implements PhysicalMachineChaosFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(PhysicalMachineChaosSpec item) {
      this.builder = new PhysicalMachineChaosSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new PhysicalMachineChaosSpecBuilder(this);
    }
    PhysicalMachineChaosSpecBuilder builder;
    public N and() {
      return (N) PhysicalMachineChaosFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends PhysicalMachineChaosStatusFluentImpl<PhysicalMachineChaosFluentImpl.StatusNested<N>> implements PhysicalMachineChaosFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(PhysicalMachineChaosStatus item) {
      this.builder = new PhysicalMachineChaosStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new PhysicalMachineChaosStatusBuilder(this);
    }
    PhysicalMachineChaosStatusBuilder builder;
    public N and() {
      return (N) PhysicalMachineChaosFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
